@@ -6,6 +6,7 @@ const defaultSettings = {
     autoCompleteUsernames: true,
     autoFillAndSend: false,
     autoFillSingleEntry: false,
+    autoFillRelevantCredential: false,
     autoFillSingleTotp: false,
     autoReconnect: false,
     autoRetrieveCredentials: true,
@@ -63,17 +64,15 @@ page.initSettings = async function() {
     try {
         const item = await browser.storage.local.get({ 'settings': {} });
 
-        // Load managed settings if found when extension is started for the first time
-        if (Object.keys(item.settings).length === 0) {
-            try {
-                const managedSettings = await browser.storage.managed.get('settings');
-                if (managedSettings?.settings) {
-                    console.log('Managed settings found.');
-                    item.settings = managedSettings.settings;
-                }
-            } catch (err) {
-                logError('page.initSettings error: ' + err);
+        // Load managed settings if found
+        try {
+            const managedSettings = await browser.storage.managed.get('settings');
+            if (managedSettings?.settings) {
+                console.log('Managed settings found.');
+                item.settings = managedSettings.settings;
             }
+        } catch (err) {
+            logError('page.initSettings error: ' + err);
         }
 
         page.settings = item.settings;
