@@ -329,22 +329,31 @@ class Autocomplete {
             return;
         }
 
-        // Calculate Y offset if menu does not fit to the bottom of the screen -> show it at the top of the input field
+        // Set container's minimum width to the input field's width
         const rect = this.input.getBoundingClientRect();
+        this.container.style.minWidth = Pixels(this.input.offsetWidth);
+        // Extend the list's max width to input field's width or at least to the maxWidth defined in the CSS file
+        this.list.style.maxWidth = `max(${Pixels(this.input.offsetWidth)}, 600px)`;
+
+        // Get body zoom radio
+        const zoom = kpxcUI.bodyStyle.zoom || 1;
+       
+        // Calculate Y offset if menu does not fit to the bottom of the screen -> show it at the top of the input field
         const menuRect = this.container.getBoundingClientRect();
         const totalHeight = menuRect.height + rect.height;
-        const menuOffset = totalHeight + rect.y > window.self.visualViewport.height ? totalHeight : 0;
+        const menuOffset = (totalHeight + rect.y) / zoom > window.self.visualViewport.height ? totalHeight / zoom : 0;
+
+        const scrollTop = kpxcUI.getScrollTop() / zoom;
+        const scrollLeft = kpxcUI.getScrollLeft() / zoom;
 
-        const scrollTop = kpxcUI.getScrollTop();
-        const scrollLeft = kpxcUI.getScrollLeft();
         if (kpxcUI.bodyStyle.position.toLowerCase() === 'relative') {
             this.container.style.top = Pixels(
-                rect.top - kpxcUI.bodyRect.top + scrollTop + this.input.offsetHeight - menuOffset,
+                ((rect.top - kpxcUI.bodyRect.top) / zoom + scrollTop + this.input.offsetHeight - menuOffset)
             );
-            this.container.style.left = Pixels(rect.left - kpxcUI.bodyRect.left + scrollLeft);
+            this.container.style.left = Pixels((rect.left - kpxcUI.bodyRect.left) / zoom + scrollLeft);
         } else {
-            this.container.style.top = Pixels(rect.top + scrollTop + this.input.offsetHeight - menuOffset);
-            this.container.style.left = Pixels(rect.left + scrollLeft);
+            this.container.style.top = Pixels(rect.top / zoom + scrollTop + this.input.offsetHeight - menuOffset);
+            this.container.style.left = Pixels(rect.left / zoom + scrollLeft);
         }
     }
 }
