@@ -6,6 +6,8 @@ const STEP_SELECT_PASSWORD = 2;
 const STEP_SELECT_TOTP = 3;
 const STEP_SELECT_STRING_FIELDS = 4;
 
+const CHECKBOX_OVERLAY_SIZE = 20;
+
 const DEFINED_CUSTOM_FIELDS = 'defined-custom-fields';
 const FIXED_FIELD_CLASS = 'kpxcDefine-fixed-field';
 const DARK_FIXED_FIELD_CLASS = 'kpxcDefine-fixed-field-dark';
@@ -17,6 +19,10 @@ const PASSWORD_FIELD_CLASS = 'kpxcDefine-fixed-password-field';
 const TOTP_FIELD_CLASS = 'kpxcDefine-fixed-totp-field';
 const STRING_FIELD_CLASS = 'kpxcDefine-fixed-string-field';
 
+const inputQueryPatternStart = 'input';
+const inputQueryPatternNotCheckbox = ':not([type=checkbox])';
+const inputQueryPattern = ':not([disabled]):not([type=button]):not([type=radio]):not([type=color]):not([type=date]):not([type=datetime-local]):not([type=file]):not([type=hidden]):not([type=image]):not([type=month]):not([type=range]):not([type=reset]):not([type=submit]):not([type=time]):not([type=week]), select, textarea';
+
 const kpxcCustomLoginFieldsBanner = {};
 kpxcCustomLoginFieldsBanner.banner = undefined;
 kpxcCustomLoginFieldsBanner.chooser = undefined;
@@ -24,7 +30,8 @@ kpxcCustomLoginFieldsBanner.created = false;
 kpxcCustomLoginFieldsBanner.dataStep = STEP_NONE;
 kpxcCustomLoginFieldsBanner.infoText = undefined;
 kpxcCustomLoginFieldsBanner.wrapper = undefined;
-kpxcCustomLoginFieldsBanner.inputQueryPattern = 'input:not([type=button]):not([type=checkbox]):not([type=color]):not([type=date]):not([type=datetime-local]):not([type=file]):not([type=hidden]):not([type=image]):not([type=month]):not([type=range]):not([type=reset]):not([type=submit]):not([type=time]):not([type=week]), select, textarea';
+kpxcCustomLoginFieldsBanner.inputQueryPatternNormal = inputQueryPatternStart + inputQueryPatternNotCheckbox + inputQueryPattern;
+kpxcCustomLoginFieldsBanner.inputQueryPatternStringFields = inputQueryPatternStart + inputQueryPattern;
 kpxcCustomLoginFieldsBanner.markedFields = [];
 kpxcCustomLoginFieldsBanner.nonSelectedElementsPattern = `div.${FIXED_FIELD_CLASS}:not(.${USERNAME_FIELD_CLASS}):not(.${PASSWORD_FIELD_CLASS}):not(.${TOTP_FIELD_CLASS}):not(.${STRING_FIELD_CLASS})`;
 
@@ -55,7 +62,8 @@ kpxcCustomLoginFieldsBanner.destroy = async function() {
     kpxcCustomLoginFieldsBanner.created = false;
     kpxcCustomLoginFieldsBanner.close();
 
-    if (kpxcCustomLoginFieldsBanner.wrapper && window.self.document.body.contains(kpxcCustomLoginFieldsBanner.wrapper)) {
+    if (kpxcCustomLoginFieldsBanner.wrapper
+        && window.self.document.body.contains(kpxcCustomLoginFieldsBanner.wrapper)) {
         window.self.document.body.removeChild(kpxcCustomLoginFieldsBanner.wrapper);
     } else {
         window.self.document.body.removeChild(window.parent.document.body.querySelector('#kpxc-banner'));
@@ -72,7 +80,10 @@ kpxcCustomLoginFieldsBanner.create = async function() {
         return;
     }
 
-    const banner = kpxcUI.createElement('div', 'kpxc-banner', { 'id': 'container' });
+    const bannerPosition = await sendMessage('banner_get_position');
+    const bannerClass =
+        bannerPosition === BannerPosition.TOP ? 'kpxc-banner kpxc-banner-on-top' : 'kpxc-banner kpxc-banner-on-bottom';
+    const banner = kpxcUI.createElement('div', bannerClass, { 'id': 'container' });
     banner.style.zIndex = '2147483646';
     kpxcCustomLoginFieldsBanner.chooser = kpxcUI.createElement('div', '', { 'id': 'kpxcDefine-fields' });
 
@@ -111,6 +122,7 @@ kpxcCustomLoginFieldsBanner.create = async function() {
     bannerButtons.appendMultiple(resetButton, separator, usernameButton,
         passwordButton, totpButton, stringFieldsButton, secondSeparator, clearDataButton, confirmButton, closeButton);
     banner.appendMultiple(bannerInfo, bannerButtons);
+    kpxcUI.makeBannerDraggable(banner);
 
     const location = kpxc.getDocumentLocation();
     kpxcCustomLoginFieldsBanner.buttons.clearData.style.display
@@ -503,7 +515,11 @@ kpxcCustomLoginFieldsBanner.selectStringFields = function() {
 
 kpxcCustomLoginFieldsBanner.markFields = function() {
     let firstInput;
-    const inputs = document.querySelectorAll(kpxcCustomLoginFieldsBanner.inputQueryPattern);
+    const inputs = document.querySelectorAll(
+        kpxcCustomLoginFieldsBanner.dataStep === STEP_SELECT_STRING_FIELDS
+            ? kpxcCustomLoginFieldsBanner.inputQueryPatternStringFields
+            : kpxcCustomLoginFieldsBanner.inputQueryPatternNormal);
+    const zoom = kpxcUI.bodyStyle.zoom || 1;
 
     for (const i of inputs) {
         if (kpxcCustomLoginFieldsBanner.isFieldSelected(i) || inputFieldIsSelected(i)) {
@@ -519,11 +535,21 @@ kpxcCustomLoginFieldsBanner.markFields = function() {
         field.originalElement = i;
 
         const rect = i.getBoundingClientRect();
-        field.style.top = Pixels(rect.top);
-        field.style.left = Pixels(rect.left);
-        field.style.width = Pixels(rect.width);
-        field.style.height = Pixels(rect.height);
-        field.textContent = dataStepToString();
+        field.style.top = Pixels(rect.top / zoom);
+        field.style.left = Pixels(rect.left / zoom);
+        field.style.width = Pixels(rect.width / zoom);
+        field.style.height = Pixels(rect.height / zoom);
+
+        // Don't show the default overlay text on checkboxes. Applied only after selection.
+        if (kpxcCustomLoginFieldsBanner.dataStep !== STEP_SELECT_STRING_FIELDS) {
+            field.textContent = dataStepToString();
+        }
+        
+        // Static size for the checkbox overlay
+        if (i?.getLowerCaseAttribute('type') === 'checkbox') {
+            field.style.width = Pixels(CHECKBOX_OVERLAY_SIZE / zoom);
+            field.style.height = Pixels(CHECKBOX_OVERLAY_SIZE / zoom);
+        }
 
         // Change selection theme if needed
         const isLightTheme = isLightThemeBackground(i);
@@ -605,14 +631,20 @@ kpxcCustomLoginFieldsBanner.monitorSelectionPosition = function(selection) {
 
 // Set selection input field position dynamically including the scroll position
 kpxcCustomLoginFieldsBanner.setSelectionPosition = function(field) {
+    const zoom = kpxcUI.bodyStyle.zoom || 1;
     const rect = field.originalElement.getBoundingClientRect();
-    const left = kpxcUI.getRelativeLeftPosition(rect);
-    const top = kpxcUI.getRelativeTopPosition(rect);
-    const scrollTop = kpxcUI.getScrollTop();
-    const scrollLeft = kpxcUI.getScrollLeft();
+    const left = kpxcUI.getRelativeLeftPosition(rect) / zoom;
+    const top = kpxcUI.getRelativeTopPosition(rect) / zoom;
+    const scrollTop = kpxcUI.getScrollTop() / zoom;
+    const scrollLeft = kpxcUI.getScrollLeft() / zoom;
 
     field.style.top = Pixels(top + scrollTop);
     field.style.left = Pixels(left + scrollLeft);
+
+    if (field.originalElement?.getLowerCaseAttribute('type') === 'checkbox') {
+        // Position the overlay to the center of checkbox
+        field.style.transform = 'translate(-25%, -25%)';
+    }
 };
 
 kpxcCustomLoginFieldsBanner.getNonSelectedElements = function() {
